summaryrefslogtreecommitdiffhomepage
path: root/examples/models_cubicmap.c
diff options
context:
space:
mode:
authorvictorfisac <[email protected]>2016-07-05 11:57:05 +0200
committervictorfisac <[email protected]>2016-07-05 11:57:05 +0200
commit1aecd5be072083e27e4289499865b5681f1ea656 (patch)
tree808159aa95df9b2be5509d83791aa6cad4ddf6b8 /examples/models_cubicmap.c
parent1b0996fb0bcf68e2a14bc6260c6f2c5366ab033f (diff)
parent2ff2096b36d80078cbda5e61ff77d7fedeeeaeb5 (diff)
downloadraylib-1aecd5be072083e27e4289499865b5681f1ea656.tar.gz
raylib-1aecd5be072083e27e4289499865b5681f1ea656.zip
Merge remote-tracking branch 'refs/remotes/raysan5/develop' into develop
Diffstat (limited to 'examples/models_cubicmap.c')
-rw-r--r--examples/models_cubicmap.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/examples/models_cubicmap.c b/examples/models_cubicmap.c
index 1ca27dfd..89bc75cf 100644
--- a/examples/models_cubicmap.c
+++ b/examples/models_cubicmap.c
@@ -29,7 +29,7 @@ int main()
// NOTE: By default each cube is mapped to one part of texture atlas
Texture2D texture = LoadTexture("resources/cubicmap_atlas.png"); // Load map texture
- SetModelTexture(&map, texture); // Bind texture to map model
+ map.material.texDiffuse = texture; // Set map diffuse texture
Vector3 mapPosition = { -16.0f, 0.0f, -8.0f }; // Set model position